@@ -1,17 +1,23 @@
 import click
 
 
-@click.command(context_settings=dict(help_option_names=['-h', '--help']))
-@click.argument('paths', nargs=-1)
-@click.option('-n', '--name-regex', metavar='regex',
-              help=r'a regex used to infer DataBlock names from paths [fallback: \d+]')
-@click.option('--strict', is_flag=True,
-              help='immediately fail if a matched path cannot be read')
-@click.option('--lazy', is_flag=True, default=True,
-              help='read data lazily (if possible)')
+@click.command(context_settings=dict(help_option_names=["-h", "--help"]))
+@click.argument("paths", nargs=-1)
+@click.option(
+    "-n",
+    "--name-regex",
+    metavar="regex",
+    help=r"a regex used to infer DataBlock names from paths [fallback: \d+]",
+)
+@click.option(
+    "--strict", is_flag=True, help="immediately fail if a matched path cannot be read"
+)
+@click.option(
+    "--lazy", is_flag=True, default=True, help="read data lazily (if possible)"
+)
 @click.version_option()
 def cli(paths, name_regex, strict, lazy):
-    """
+    r"""
     naaf command line interface.
 
     Opens files and lands in an interactive ipython shell with data loaded as `data`
@@ -34,20 +40,21 @@ def cli(paths, name_regex, strict, lazy):
         naaf /path/to/dir/MyProtein* -n 'Protein_\d+'
     """
     if not paths:
-        paths = ['./*']
+        paths = ["./*"]
 
-    import naaf
     from IPython.terminal.embed import InteractiveShellEmbed
 
-    data = naaf.read(
-        *paths,  # noqa: F841
-         name_regex=name_regex,
-         strict=strict,
-         lazy=lazy,
-     )
+    import naaf
+
+    data = naaf.read(  # noqa: F841
+        *paths,
+        name_regex=name_regex,
+        strict=strict,
+        lazy=lazy,
+    )
 
     # set up ipython shell nicely
-    banner = '=== naaf ==='
+    banner = "=== naaf ==="
     sh = InteractiveShellEmbed(banner2=banner)
-    sh.push('data')
+    sh.push("data")
     sh()
